@@ -131,7 +131,7 @@ class MainWindow(QtWidgets.QMainWindow):
         splitter2.addWidget(container2)
         splitter2.addWidget(scrollable_message)
         splitter2.setCollapsible(0, False)
-        splitter2.setCollapsible(1, False)
+        splitter2.setCollapsible(1, True)
         splitter2.splitterMoved.connect(self.splitter_moved)
 
         self.setCentralWidget(splitter2)
@@ -624,6 +624,8 @@ class MainWindow(QtWidgets.QMainWindow):
         self.handle_keypress(event)
 
     def handle_keypress(self, e):
+        if e.matches(QtGui.QKeySequence.Copy):
+            self.logtable.copy_selection()
         if e.key() == Qt.Key_Right:
             self.next_frame()
         elif e.key() == Qt.Key_Left:
